# Purpose: Creates the csv tables that allow county boundaries to be synchronized to a base year, exported to the directory you run this from.  
# 	It also ends up creating classes with the intersected boundaries in it. They can be deleted through acrGIS catalog viewer.

# Import the arcpy and os modules.
import arcpy
import os
import string

#Set the parameters for the program:

# Input the feature classes to buffer.
# The first of these can be a list of different shapefiles (years).  The base year must be one class.

#Years to convert
#When running as a toolbox
inFC_to_change = arcpy.GetParameterAsText(0)
#When running from command line put the paths to the classes here.
#inFC_to_change = r'.\nhgis_shapefile_tl2008_us_county_1790_1900\nhgis0003_shapefile_tl2008_us_county_1790\US_county_1790_conflated.shp;.\nhgis_shapefile_tl2008_us_county_1790_1900\nhgis0003_shapefile_tl2008_us_county_1800\US_county_1800_conflated.shp;.\nhgis_shapefile_tl2008_us_county_1790_1900\nhgis0003_shapefile_tl2008_us_county_1810\US_county_1810_conflated.shp;.\nhgis_shapefile_tl2008_us_county_1790_1900\nhgis0003_shapefile_tl2008_us_county_1820\US_county_1820_conflated.shp;.\nhgis_shapefile_tl2008_us_county_1790_1900\nhgis0003_shapefile_tl2008_us_county_1830\US_county_1830_conflated.shp;.\nhgis_shapefile_tl2008_us_county_1790_1900\nhgis0003_shapefile_tl2008_us_county_1840\US_county_1840_conflated.shp;.\nhgis_shapefile_tl2008_us_county_1790_1900\nhgis0003_shapefile_tl2008_us_county_1850\US_county_1850_conflated.shp;.\nhgis_shapefile_tl2008_us_county_1790_1900\nhgis0003_shapefile_tl2008_us_county_1860\US_county_1860_conflated.shp;.\nhgis_shapefile_tl2008_us_county_1790_1900\nhgis0003_shapefile_tl2008_us_county_1870\US_county_1870_conflated.shp;.\nhgis_shapefile_tl2008_us_county_1790_1900\nhgis0003_shapefile_tl2008_us_county_1880\US_county_1880_conflated.shp;.\nhgis_shapefile_tl2008_us_county_1790_1900\nhgis0003_shapefile_tl2008_us_county_1890\US_county_1890_conflated.shp;.\nhgis_shapefile_tl2008_us_county_1790_1900\nhgis0003_shapefile_tl2008_us_county_1900\US_county_1900_conflated.shp'

#Base year
#When running as a toolbox
inFC_base_year = arcpy.GetParameterAsText(1)
#When running from command line put the paths to the classes here.
#inFC_base_year = r'.\nhgis_shapefile_tl2008_us_county_1790_1900\nhgis0003_shapefile_tl2008_us_county_1840\US_county_1840_conflated.shp'

#The base year as text.  This is used to name the output classes and files.
#When running as a toolbox
base_year = arcpy.GetParameterAsText(2)
#When running from command line
#base_year = 1840

#Set the output workspace.  I just go with a default.
#When running as a toolbox
outWS = arcpy.GetParameterAsText(3)
#When running from command line
#outWS = r'C:\Users\bitsy\Documents\ArcGIS\Default1.gdb'





# Split input feature classes that are being changed into separate feature classes.
inFC_to_change = inFC_to_change.split(";")

# Loop through each feature class and 
for inFC in inFC_to_change:

	#Check to see if the area has been calculated and is named Area_SqMi
	fields = arcpy.ListFields(inFC)
	area_exists = False
	for field in fields:
		if string.lower(field.name) == string.lower("Area_SqMi"): 
			print "Area_SqMi exists"
			area_exists = True
		# if x <> True:
			# print "Area does not exist"
			
	#Calculate the area (square miles) if it has not been calculated. 
	#This may error if the shapefiles you are using haven't been projected, so areas cannot be calculated.
	#I use the USA_Contiguous_Albers_Equal_Area_Conic projection, whatever you use make sure it is constant between shapefiles.
	if area_exists <> True:
		print "Making Area_SqMi"
		#Add a Field
		arcpy.AddField_management (inFC, "Area_SqMi", "DOUBLE", 10000000, 10000000)
		arcpy.CalculateField_management (inFC, "Area_SqMi", '!shape.area@squaremiles!', "PYTHON")
	
	#Create the intersection
	#Figure out the name of the output feature class.
	(filePath, fileName) = os.path.split(inFC)
	dotInd = fileName.find(".")
	if dotInd <> -1:
		newFC = fileName[0:dotInd]
		outFC = newFC + "_b" + str(base_year) + "_Int"
	else:
		outFC = fileName + "_b" + str(base_year) + "_Int"
	
	#Combine this name with the output work space
	out_GDB_name = outWS + "\\" + outFC
	
	#Double check to see that it doesn't have a .shp on it
	dotInd = out_GDB_name.find(".s")
	if dotInd <> -1:
		out_GDB_name = out_GDB_name[0:dotInd]
	
	print "Preforming Intersect"
	arcpy.Intersect_analysis ([inFC, inFC_base_year], out_GDB_name)
	
	#Calculate the area of the intersected values.
	#See the above note about projections.
	print "Making Area_SqMiI"
	arcpy.AddField_management (out_GDB_name, "Area_SqMiI", "DOUBLE", 10000000, 10000000)
	arcpy.CalculateField_management (out_GDB_name, "Area_SqMiI", '!shape.area@squaremiles!', "PYTHON")
	
	#Export the data that was just calculated as a csv
	print "Exporting Data"
	out_name = "Export_" + outFC + ".csv"
	arcpy.ExportXYv_stats (out_GDB_name, ["DECADE", "ICPSRFIP", "GISJOIN", "Area_SqMi", "DECADE_1", "ICPSRFIP_1", "GISJOIN_1", "Area_SqMi_1", "Area_SqMiI"], "COMMA", out_name,"ADD_FIELD_NAMES")